==> sil_machine-1.6.2.tar.gz: sil_machine-1.6.2/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .alignment_collection import AlignmentCollection
from .alignment_corpus import AlignmentCorpus
from .alignment_row import AlignmentRow
from .corpora_utils import batch
from .corpus import Corpus
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_alignment_corpus import DictionaryAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .file_paratext_project_settings_parser import FileParatextProjectSettingsParser
from .file_paratext_project_text_updater import FileParatextProjectTextUpdater
from .flatten import flatten
from .memory_alignment_collection import MemoryAlignmentCollection
from .memory_stream_container import MemoryStreamContainer
from .memory_text import MemoryText
from .multi_key_ref import MultiKeyRef
from .parallel_text_corpus import ParallelTextCorpus
from .parallel_text_row import ParallelTextRow
from .paratext_backup_terms_corpus import ParatextBackupTermsCorpus
from .paratext_backup_text_corpus import ParatextBackupTextCorpus
from .paratext_project_settings import ParatextProjectSettings
from .paratext_project_settings_parser_base import ParatextProjectSettingsParserBase
from .paratext_project_terms_parser_base import ParatextProjectTermsParserBase
from .paratext_project_text_updater_base import ParatextProjectTextUpdaterBase
from .paratext_text_corpus import ParatextTextCorpus
from .scripture_element import ScriptureElement
from .scripture_ref import EMPTY_SCRIPTURE_REF, ScriptureRef
from .scripture_ref_usfm_parser_handler import ScriptureRefUsfmParserHandler, ScriptureTextType
from .scripture_text_corpus import (
    ScriptureTextCorpus,
    create_versification_ref_corpus,
    extract_scripture_corpus,
    is_scripture,
)
from .standard_parallel_text_corpus import StandardParallelTextCorpus
from .text import Text
from .text_corpus import TextCorpus
from .text_file_alignment_collection import TextFileAlignmentCollection
from .text_file_alignment_corpus import TextFileAlignmentCorpus
from .text_file_text import TextFileText
from .text_file_text_corpus import TextFileTextCorpus
from .text_row import TextRow, TextRowFlags
from .token_processors import (
    escape_spaces,
    lowercase,
    nfc_normalize,
    nfd_normalize,
    nfkc_normalize,
    nfkd_normalize,
    normalize,
    unescape_spaces,
)
from .update_usfm_parser_handler import UpdateUsfmMarkerBehavior, UpdateUsfmParserHandler, UpdateUsfmTextBehavior
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_memory_text import UsfmMemoryText
from .usfm_parser import UsfmParser, parse_usfm
from .usfm_parser_handler import UsfmParserHandler
from .usfm_parser_state import UsfmElementType, UsfmParserElement, UsfmParserState
from .usfm_stylesheet import UsfmStylesheet
from .usfm_tag import UsfmJustification, UsfmStyleAttribute, UsfmStyleType, UsfmTag, UsfmTextProperties, UsfmTextType
from .usfm_token import UsfmAttribute, UsfmToken, UsfmTokenType
from .usfm_tokenizer import RtlReferenceOrder, UsfmTokenizer
from .usx_file_alignment_collection import UsxFileAlignmentCollection
from .usx_file_alignment_corpus import UsxFileAlignmentCorpus
from .usx_file_text import UsxFileText
from .usx_file_text_corpus import UsxFileTextCorpus
from .usx_memory_text import UsxMemoryText
from .usx_zip_text import UsxZipText
from .zip_paratext_project_settings_parser import ZipParatextProjectSettingsParser
from .zip_paratext_project_settings_parser_base import ZipParatextProjectSettingsParserBase
from .zip_paratext_project_terms_parser import ZipParatextProjectTermsParser
from .zip_paratext_project_text_updater import ZipParatextProjectTextUpdater

__all__ = [
    "AlignedWordPair",
    "AlignmentCollection",
    "AlignmentCorpus",
    "AlignmentRow",
    "batch",
    "Corpus",
    "create_versification_ref_corpus",
    "DblBundleTextCorpus",
    "DictionaryAlignmentCorpus",
    "DictionaryTextCorpus",
    "EMPTY_SCRIPTURE_REF",
    "escape_spaces",
    "extract_scripture_corpus",
    "FileParatextProjectSettingsParser",
    "FileParatextProjectTextUpdater",
    "flatten",
    "is_scripture",
    "lowercase",
    "MemoryAlignmentCollection",
    "MemoryText",
    "MemoryStreamContainer",
    "MultiKeyRef",
    "nfc_normalize",
    "nfd_normalize",
    "nfkc_normalize",
    "nfkd_normalize",
    "normalize",
    "ParallelTextCorpus",
    "ParallelTextRow",
    "ParatextBackupTermsCorpus",
    "ParatextBackupTextCorpus",
    "ParatextProjectSettings",
    "ParatextProjectSettingsParserBase",
    "ParatextProjectTermsParserBase",
    "ParatextProjectTextUpdaterBase",
    "ParatextTextCorpus",
    "parse_usfm",
    "RtlReferenceOrder",
    "ScriptureElement",
    "ScriptureRef",
    "ScriptureRefUsfmParserHandler",
    "ScriptureTextCorpus",
    "ScriptureTextType",
    "StandardParallelTextCorpus",
    "Text",
    "TextCorpus",
    "TextFileAlignmentCollection",
    "TextFileAlignmentCorpus",
    "TextFileText",
    "TextFileTextCorpus",
    "TextRow",
    "TextRowFlags",
    "unescape_spaces",
    "UpdateUsfmTextBehavior",
    "UpdateUsfmMarkerBehavior",
    "UpdateUsfmParserHandler",
    "UsfmAttribute",
    "UsfmElementType",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmMemoryText",
    "UsfmParser",
    "UsfmParserElement",
    "UsfmParserHandler",
    "UsfmParserState",
    "UsfmStyleAttribute",
    "UsfmStylesheet",
    "UsfmStyleType",
    "UsfmTag",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsfmToken",
    "UsfmTokenizer",
    "UsfmTokenType",
    "UsxFileAlignmentCollection",
    "UsxFileAlignmentCorpus",
    "UsxFileText",
    "UsxFileTextCorpus",
    "UsxMemoryText",
    "UsxZipText",
    "ZipParatextProjectSettingsParser",
    "ZipParatextProjectSettingsParserBase",
    "ZipParatextProjectTermsParser",
    "ZipParatextProjectTextUpdater",
]

==> sil_machine-1.7.4.tar.gz: sil_machine-1.7.4/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .alignment_collection import AlignmentCollection
from .alignment_corpus import AlignmentCorpus
from .alignment_row import AlignmentRow
from .corpora_utils import batch
from .corpus import Corpus
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_alignment_corpus import DictionaryAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .file_paratext_project_settings_parser import FileParatextProjectSettingsParser
from .file_paratext_project_text_updater import FileParatextProjectTextUpdater
from .flatten import flatten
from .memory_alignment_collection import MemoryAlignmentCollection
from .memory_stream_container import MemoryStreamContainer
from .memory_text import MemoryText
from .multi_key_ref import MultiKeyRef
from .parallel_text_corpus import ParallelTextCorpus
from .parallel_text_row import ParallelTextRow
from .paratext_backup_terms_corpus import ParatextBackupTermsCorpus
from .paratext_backup_text_corpus import ParatextBackupTextCorpus
from .paratext_project_settings import ParatextProjectSettings
from .paratext_project_settings_parser_base import ParatextProjectSettingsParserBase
from .paratext_project_terms_parser_base import ParatextProjectTermsParserBase
from .paratext_project_text_updater_base import ParatextProjectTextUpdaterBase
from .paratext_text_corpus import ParatextTextCorpus
from .place_markers_usfm_update_block_handler import PlaceMarkersAlignmentInfo, PlaceMarkersUsfmUpdateBlockHandler
from .scripture_element import ScriptureElement
from .scripture_ref import EMPTY_SCRIPTURE_REF, ScriptureRef
from .scripture_ref_usfm_parser_handler import ScriptureRefUsfmParserHandler, ScriptureTextType
from .scripture_text_corpus import (
    ScriptureTextCorpus,
    create_versification_ref_corpus,
    extract_scripture_corpus,
    is_scripture,
)
from .standard_parallel_text_corpus import StandardParallelTextCorpus
from .text import Text
from .text_corpus import TextCorpus
from .text_file_alignment_collection import TextFileAlignmentCollection
from .text_file_alignment_corpus import TextFileAlignmentCorpus
from .text_file_text import TextFileText
from .text_file_text_corpus import TextFileTextCorpus
from .text_row import TextRow, TextRowFlags
from .token_processors import (
    escape_spaces,
    lowercase,
    nfc_normalize,
    nfd_normalize,
    nfkc_normalize,
    nfkd_normalize,
    normalize,
    unescape_spaces,
)
from .update_usfm_parser_handler import (
    UpdateUsfmMarkerBehavior,
    UpdateUsfmParserHandler,
    UpdateUsfmRow,
    UpdateUsfmTextBehavior,
)
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_memory_text import UsfmMemoryText
from .usfm_parser import UsfmParser, parse_usfm
from .usfm_parser_handler import UsfmParserHandler
from .usfm_parser_state import UsfmElementType, UsfmParserElement, UsfmParserState
from .usfm_stylesheet import UsfmStylesheet
from .usfm_tag import UsfmJustification, UsfmStyleAttribute, UsfmStyleType, UsfmTag, UsfmTextProperties, UsfmTextType
from .usfm_token import UsfmAttribute, UsfmToken, UsfmTokenType
from .usfm_tokenizer import RtlReferenceOrder, UsfmTokenizer
from .usfm_update_block import UsfmUpdateBlock
from .usfm_update_block_element import UsfmUpdateBlockElement, UsfmUpdateBlockElementType
from .usfm_update_block_handler import UsfmUpdateBlockHandler
from .usx_file_alignment_collection import UsxFileAlignmentCollection
from .usx_file_alignment_corpus import UsxFileAlignmentCorpus
from .usx_file_text import UsxFileText
from .usx_file_text_corpus import UsxFileTextCorpus
from .usx_memory_text import UsxMemoryText
from .usx_zip_text import UsxZipText
from .zip_paratext_project_settings_parser import ZipParatextProjectSettingsParser
from .zip_paratext_project_settings_parser_base import ZipParatextProjectSettingsParserBase
from .zip_paratext_project_terms_parser import ZipParatextProjectTermsParser
from .zip_paratext_project_text_updater import ZipParatextProjectTextUpdater

__all__ = [
    "AlignedWordPair",
    "AlignmentCollection",
    "AlignmentCorpus",
    "AlignmentRow",
    "batch",
    "Corpus",
    "create_versification_ref_corpus",
    "DblBundleTextCorpus",
    "DictionaryAlignmentCorpus",
    "DictionaryTextCorpus",
    "EMPTY_SCRIPTURE_REF",
    "escape_spaces",
    "extract_scripture_corpus",
    "FileParatextProjectSettingsParser",
    "FileParatextProjectTextUpdater",
    "flatten",
    "is_scripture",
    "lowercase",
    "MemoryAlignmentCollection",
    "MemoryStreamContainer",
    "MemoryText",
    "MultiKeyRef",
    "nfc_normalize",
    "nfd_normalize",
    "nfkc_normalize",
    "nfkd_normalize",
    "normalize",
    "ParallelTextCorpus",
    "ParallelTextRow",
    "ParatextBackupTermsCorpus",
    "ParatextBackupTextCorpus",
    "ParatextProjectSettings",
    "ParatextProjectSettingsParserBase",
    "ParatextProjectTermsParserBase",
    "ParatextProjectTextUpdaterBase",
    "ParatextTextCorpus",
    "PlaceMarkersAlignmentInfo",
    "PlaceMarkersUsfmUpdateBlockHandler",
    "parse_usfm",
    "RtlReferenceOrder",
    "ScriptureElement",
    "ScriptureRef",
    "ScriptureRefUsfmParserHandler",
    "ScriptureTextCorpus",
    "ScriptureTextType",
    "StandardParallelTextCorpus",
    "Text",
    "TextCorpus",
    "TextFileAlignmentCollection",
    "TextFileAlignmentCorpus",
    "TextFileText",
    "TextFileTextCorpus",
    "TextRow",
    "TextRowFlags",
    "unescape_spaces",
    "UpdateUsfmMarkerBehavior",
    "UpdateUsfmParserHandler",
    "UpdateUsfmTextBehavior",
    "UpdateUsfmRow",
    "UsfmAttribute",
    "UsfmElementType",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmMemoryText",
    "UsfmParser",
    "UsfmParserElement",
    "UsfmParserHandler",
    "UsfmParserState",
    "UsfmStyleAttribute",
    "UsfmStylesheet",
    "UsfmStyleType",
    "UsfmTag",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsfmToken",
    "UsfmTokenizer",
    "UsfmTokenType",
    "UsfmUpdateBlock",
    "UsfmUpdateBlockElement",
    "UsfmUpdateBlockElementType",
    "UsfmUpdateBlockHandler",
    "UsxFileAlignmentCollection",
    "UsxFileAlignmentCorpus",
    "UsxFileText",
    "UsxFileTextCorpus",
    "UsxMemoryText",
    "UsxZipText",
    "ZipParatextProjectSettingsParser",
    "ZipParatextProjectSettingsParserBase",
    "ZipParatextProjectTermsParser",
    "ZipParatextProjectTextUpdater",
]
